import RPGIndicators2Frame;
import RPGIndicatorList;
import java.util.StringTokenizer;

/**
 *
 * This class is an Lpexlet.  It subclasses LpexCommand, the Lpex Java
 * Programming Interface.
 * It displays a window that lists the indicators used in the document.
 * For each indicator, the list of lines it appears on are displayed.
 * Double-clicking on a line number positions the cursor on the line in
 * the editor window.
 * This version uses JFC (Swing) which allows the use of a tree.
 *
 * @author Eric Simpson
 * @version 1.0
 * @see RPGIndicators2Frame
 * @see RPGIndicators
 * @see RPGIndicatorList
 */
public class RPGIndicators2 extends LpexCommand
{
  static RPGIndicators2Frame tframe = null;

  /**
   *  lpexEntry() - main entry point from LPEX.  Create window listing
   *  indicators for current document.  If window already exists, update its
   *  list of indicators for the current document.
   */
  public static int lpexEntry (String arg)
  {
     if (arg.length() != 0)
     {
        // arguments specified
     }

     String profile = lpexGetParm( "PROFILE" );

     if ( profile.equals("VRPG400") || profile.equals("RPG400") || profile.equals("RPGLE400") )
     {
       int n = lpexGetIntParm("DOCNUM");
       if (tframe == null) // none yet: put up the window
       {
         if ( n != 0 )
           tframe = new RPGIndicators2Frame( lpexGetParm( "NAME" ) );
       }
       else               // one at any given time is plenty...
       {
         if ( n != 0 )
           tframe.refresh( lpexGetParm( "NAME" ) );
         tframe.show();
         tframe.toFront();
       }
     }  // end if VPRG, RPG, ILE RPG
     else
       lpexCall("MSG","RPGIndicators2 only works with VPRG, OPM RPG, and ILE RPG source");

     return 0;                             // return a good return code to LPEX
  }  // end of lpexEntry

  /**
   *  lpexNotify() - tell LPEX to notify us on exit.
   */
  public static int lpexNotify ()
  {
     return LPEX_NOTIFY_EXIT;
  }  // end of lpexNotify

  /**
   *  lpexExit() - we're being terminated, dispose of the window
   */
  public static int lpexExit (String arg)
  {
     tframe.dispose();                                // get rid of the window
     return 0;
  }  // end of lpexExit


}  // end of RPGIndicators2