import java.awt.*;
import java.awt.event.*;
import com.sun.java.swing.*;
import com.sun.java.swing.tree.*;
import com.sun.java.swing.event.*;
import java.util.StringTokenizer;
import RPGIndicators2;
import RPGIndicatorList;

/**
 * A class representing a window.  On the window, it displays a tree of the line
 * numbers for each of the indicators found in the document, and a
 * button to refresh the list.  Uses JFC (Swing).
 *
 * @author Eric Simpson
 * @version 1.0
 * @see RPGIndicators2
 */
public class RPGIndicators2Frame extends JFrame implements TreeSelectionListener, ActionListener
{
  private DefaultMutableTreeNode root;
  private JTree                  theTree;
  private JButton                buttonRefresh;
  private String                 docName;
  private JScrollPane            scrollPane;

  /**
   *  constructor for RPGIndicators2Frame, sets up window, populates tree
   */
  public RPGIndicators2Frame(String docname)
  {
    super("RPG Indicators");
    docName = docname;
    getContentPane().setLayout(new BorderLayout());

    scrollPane = new JScrollPane();
    scrollPane.setPreferredSize(new Dimension(200, 300));
    refresh();
    getContentPane().add(scrollPane, BorderLayout.CENTER);
    getContentPane().add(buttonRefresh = constructRefreshButton(), BorderLayout.SOUTH);

    // listen to the toolbar window being asked to close (Alt+F4)
    this.addWindowListener(new WindowEventHandler());

    setLocation(10,10);
    pack();
    show();
  }  // end of constructor


  /**
   * Populate our tree. This is separated so it can be run in a thread
   */
  public int populateTree()
  {
    DefaultMutableTreeNode child;
    DefaultMutableTreeNode indicatorNode;

    // create a new tree node
    root = new DefaultMutableTreeNode(new String(docName));

    RPGIndicatorList list = RPGIndicators.getIndicators( docName );
    // if empty list, just add node to indicate no indicators were found
    if ( list.size() == 0 )
    {
      child = new DefaultMutableTreeNode(new String("--- No indicators found ---"));
      root.add(child);
    }
    else
    {
      // go through list and add nodes for each indicator and nodes for each line
      // line number
      list.resetCursor();
      while (list.hasMoreElements())
      {
        String indicator = list.currentElementIndicator();
        String lines = list.currentElementData();
        StringTokenizer st = new StringTokenizer( lines );

        indicatorNode = new DefaultMutableTreeNode(new String(indicator));
        root.add(indicatorNode);

        while ( st.hasMoreTokens() )
        {
          String line = st.nextToken();
          child = new DefaultMutableTreeNode(new String(line));
          indicatorNode.add(child);
        }  // end while more line numbers to add

        list.nextElement();
      }  // end while list has more elements
    }  // end else list has indicators

    return list.size();
  }  // end of populate()


  /**
   * This is called by Java when an item in the tree is selected
   */
  public void valueChanged(TreeSelectionEvent e)
  {
    TreePath lastItemPath = e.getNewLeadSelectionPath();
    DefaultMutableTreeNode treeNode = (DefaultMutableTreeNode)lastItemPath.getLastPathComponent();

    // leaf nodes are line numbers unless it is a node "--- No indicators found ---"
    // if a real line number, position the cursor in the editor
    if ( treeNode.isLeaf() )
    {
      String selectedNode = (String) treeNode.getUserObject();
      if ( selectedNode.charAt(0) != '-' )
        RPGIndicators.positionToIndicator( docName, selectedNode );
    }  // end if node is leaf
  } // end of method valueChanged from TreeSelectionListener


  /**
   * This is called by Java when a button is selected
   */
  public void actionPerformed(ActionEvent e)
  {
    Object item = e.getSource();
    if (item == buttonRefresh)
    {
      refresh();
    }  // end if buttonRefresh
  } // end of method actionPerformed


  /**
   * Constructs a JButton for refresh
   */
  private JButton constructRefreshButton()
  {
    buttonRefresh = new JButton("Refresh");
    buttonRefresh.setToolTipText("Refresh contents of the tree");
    buttonRefresh.addActionListener(this);

    return buttonRefresh;
  } // end constructOptionsPanel method


  /**
   * Refresh the list of indicators
   */
  public void refresh ()
  {
    populateTree(); // will reset the root variable
    theTree = new JTree(root);
    theTree.addTreeSelectionListener(this);
    // put tree in scrollpane
    scrollPane.getViewport().setView(null);
    scrollPane.getViewport().add(theTree);

    show();
  }  // end of refresh()


  /**
   * refresh( String ) - refresh the contents of the list using
   * new document name
   */
  public void refresh ( String name )
  {
    docName = name;
    refresh();
  }  // end of refresh( String )


  class WindowEventHandler extends WindowAdapter
  {
    public void windowClosing (WindowEvent evt)
    {
      dispose();
    }
  }
} // end RPGIndicators2Frame class